@@ -1,5 +1,5 @@
 import typer
-from fastapi_admin.commands import project, app, container, migrations, docker
+from fastapi_admin.commands import project, app, container, migrations, docker, superuser
 
 cli_app = typer.Typer(
     help="FastAPI Admin CLI tool for managing FastAPI applications")
@@ -12,6 +12,8 @@ cli_app.add_typer(container.app, name="shell")
 cli_app.add_typer(migrations.app, name="db")
 # Access as: fastapi-admin docker build
 cli_app.add_typer(docker.app, name="docker")
+# Access as: fastapi-admin createsuperuser
+cli_app.add_typer(superuser.app, name="createsuperuser")
 
 
 def cli():
