@@ -1,7 +1,6 @@
 import typer
 import os
 import requests
-from typing import Optional
 from rich.console import Console
 from rich.panel import Panel
 
@@ -12,23 +11,19 @@ app = typer.Typer(
 console = Console()
 
 SCRIPT_URL = "https://raw.githubusercontent.com/amal-babu-git/fastapi-admin-cli-template/refs/heads/main/scripts/create_superuser.py"
+# if the user using this command first time, we need to rebuilt docker because script folder is empty
 
 
 @app.callback(invoke_without_command=True)
 def main(
     email: str = typer.Argument(..., help="Email of the superuser"),
     password: str = typer.Argument(..., help="Password for the superuser"),
-    first_name: Optional[str] = typer.Option(
-        None, help="First name of the superuser"),
-    last_name: Optional[str] = typer.Option(
-        None, help="Last name of the superuser")
 ):
     """
     Create a superuser for the admin panel.
 
     Example:
         $ fastapi-admin createsuperuser admin@example.com password123
-        $ fastapi-admin createsuperuser admin@example.com password123 --first-name Admin --last-name User
     """
     console.print(Panel(
         f"Creating superuser with email: [bold blue]{email}[/]",
@@ -37,7 +32,7 @@ def main(
 
     try:
         # We need to execute inside the container where the database is accessible
-        _create_superuser_in_container(email, password, first_name, last_name)
+        _create_superuser_in_container(email, password)
 
         console.print(Panel(
             f"[bold green]✓ Superuser {email} created successfully![/]",
@@ -52,7 +47,7 @@ def main(
         raise typer.Exit(code=1)
 
 
-def _create_superuser_in_container(email: str, password: str, first_name: Optional[str], last_name: Optional[str]):
+def _create_superuser_in_container(email: str, password: str):
     """Execute superuser creation inside the Docker container"""
     import subprocess
 
@@ -78,7 +73,8 @@ def _create_superuser_in_container(email: str, password: str, first_name: Option
                 f.write(response.text)
 
             console.print(
-                f"[green]✓ Script downloaded successfully to {script_path}\n")
+                f"[green]✓ Script downloaded successfully to {script_path}[/]")
+
         except Exception as e:
             console.print(
                 f"[bold red]Failed to download the script:[/] {str(e)}")
@@ -94,20 +90,20 @@ def _create_superuser_in_container(email: str, password: str, first_name: Option
         docker_cmd = "docker compose"
 
     # Build command arguments
-    command_args = ["python", "scripts/create_superuser.py", email, password]
-    if first_name:
-        command_args.extend(["--first-name", first_name])
-    if last_name:
-        command_args.extend(["--last-name", last_name])
+    command_args = [
+        "python", "/app/scripts/create_superuser.py", email, password]
 
     command = " ".join(command_args)
 
     console.print(f"[dim]Executing: {command}[/dim]")
 
+    # Mount local scripts directory to /app/scripts in the container
+    volume_mount = f"-v {script_dir}:/app/scripts"
+
     try:
-        # Run the script in the container
+        # Run the script in the container with volume mount
         result = subprocess.run(
-            f"{docker_cmd} -f docker/compose/docker-compose.yml exec api {command}",
+            f'{docker_cmd} -f docker/compose/docker-compose.yml run --rm {volume_mount} api sh -c "{command}"',
             shell=True,
             check=True,
             capture_output=True,
@@ -178,6 +174,24 @@ def _create_superuser_in_container(email: str, password: str, first_name: Option
                 border_style="red"
             ))
 
+        # Handle script not found errors
+        if hasattr(e, 'stderr') and e.stderr and "No such file or directory" in e.stderr:
+            console.print(Panel(
+                "\n".join([
+                    "[bold red]Script not found in container[/]",
+                    "",
+                    "The create_superuser.py script couldn't be found in the container.",
+                    "This could be due to a volume mounting issue.",
+                    "",
+                    "[yellow]Try manually copying the script to your container:[/]",
+                    f"1. Make sure the script exists at {script_path}",
+                    "2. Ensure proper permissions on the script file",
+                    "3. Check Docker volume mounting permissions"
+                ]),
+                title="Script Access Error",
+                border_style="red"
+            ))
+
         console.print(Panel(
             f"[bold red]Failed to create superuser:[/]\n\n"
             f"[bold white]STDOUT:[/]\n{e.stdout if hasattr(e, 'stdout') and e.stdout else 'No output'}\n\n"
